@@ -615,7 +615,7 @@ newPop = function(rawPop,simParam=NULL,...){
   return(.newPop(rawPop=rawPop,simParam=simParam,...))
 }
 
-#' @title Create new population (internal)
+#' @title Create new population
 #'
 #' @description
 #' Creates a new \code{\link{Pop-class}} from an object of
@@ -636,6 +636,8 @@ newPop = function(rawPop,simParam=NULL,...){
 #' function in simParam
 #'
 #' @return Returns an object of \code{\link{Pop-class}}
+#' 
+#' @keywords internal
 .newPop = function(rawPop, id=NULL, mother=NULL, father=NULL,
                    iMother=NULL, iFather=NULL, isDH=NULL,
                    femaleParentPop=NULL, maleParentPop=NULL,
@@ -711,14 +713,19 @@ newPop = function(rawPop,simParam=NULL,...){
   pheno = gv
 
   if(simParam$nTraits>=1){
+    tmp = getGvIndex(rawPop, simParam$traits, simParam$activeQtl, 
+                     simParam$qtlIndex, simParam$nTraits, simParam$nThreads)
+    
+    gv = tmp[[1]]
+    colnames(gv) = simParam$traitNames
+    
+    gxeTmp = tmp[[2]]
+    dim(gxeTmp) = NULL # Account for matrix bug in RcppArmadillo
+    
+    # Move over gxeTmp for traits with GxE
     for(i in seq_len(simParam$nTraits)){
-      tmp = getGv(simParam$traits[[i]], rawPop, simParam$nThreads)
-      gv[,i] = tmp[[1]]
-
-      colnames(gv)[i] = simParam$traits[[i]]@name
-
-      if(length(tmp)>1){
-        gxe[[i]] = tmp[[2]]
+      if(.hasSlot(simParam$traits[[i]], "gxeEff")){
+        gxe[[i]] = gxeTmp[[i]]
       }
     }
   }
@@ -750,7 +757,7 @@ newPop = function(rawPop,simParam=NULL,...){
                       simParam=simParam)
   }
 
-  output = simParam$finalizePop(output,...)
+  output = simParam$finalizePop(output, simParam=simParam, ...)
 
   if(simParam$isTrackPed){
     if(simParam$isTrackRec){
